==> flutter_bdface_plugin-0.0.2.tar.gz: example/lib/main.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_bdface_plugin/flutter_bdface_plugin.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  var headBytes;
  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await FlutterBdfacePlugin.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
          appBar: AppBar(
            title: const Text('Plugin example app'),
          ),
          body: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              if(headBytes!=null)
              Center(
                child: Image.memory(headBytes,fit: BoxFit.cover, width: 100),
              ),
              Center(
                child:RaisedButton(
                    child: Text("打开liveness"),
                    onPressed: () {
                      _liveness();
                    }),
              ),
              Center(
                child:RaisedButton(
                    child: Text("打开detect"),
                    onPressed: () {
                      _detect();
                    }),
              )
            ],
          )),
    );
  }

  _liveness() async {
    LivenessResult result = await new FlutterBdfacePlugin().liveness();
    print(result.success);
    print(result.image);
    if(result.success== "true"){
      var bytes = Base64Decoder().convert(result.image);
      setState(() {
        headBytes = bytes;
      });
    }
    // setState
  }

  _detect() async {
    DetectResult result = await new FlutterBdfacePlugin().detect();
    print(result.success);
    print(result.image);
    if(result.success== "true"){
      var bytes = Base64Decoder().convert(result.image);
      setState(() {
        headBytes = bytes;
      });
    }
    // setState
  }
}

==> flutter_bdface_plugin-2.0.1.tar.gz: example/lib/main.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_bdface_plugin/flutter_bdface_plugin.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  var headBytes;
  @override
  void initState() {
    super.initState();
    if(Platform.isIOS){
      new FlutterBdfacePlugin().initIosSdk("sinosoft-face-ios");
    }
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await FlutterBdfacePlugin.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
          appBar: AppBar(
            title: const Text('Plugin example app'),
          ),
          body: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              if(headBytes!=null)
              Center(
                child: Image.memory(headBytes,fit: BoxFit.cover, width: 100),
              ),
              Center(
                child:RaisedButton(
                    child: Text("打开liveness"),
                    onPressed: () {
                      _liveness();
                    }),
              ),
              Center(
                child:RaisedButton(
                    child: Text("打开detect"),
                    onPressed: () {
                      _detect();
                    }),
              )
            ],
          )),
    );
  }

  _liveness() async {
    LivenessResult result = await new FlutterBdfacePlugin().liveness();
    print(result.success);
    print(result.image);
    if(result.success== "true"){
      var base64 = result.image.replaceAll('\r', '').replaceAll('\n', '');
      var bytes = Base64Decoder().convert(base64);
      setState(() {
        headBytes = bytes;
      });
    }
    // setState
  }

  _detect() async {
    DetectResult result = await new FlutterBdfacePlugin().detect();
    print(result.success);
    print(result.image);

    if(result.success== "true"){
      var base64 = result.image.replaceAll('\r', '').replaceAll('\n', '');
      var bytes = Base64Decoder().convert(base64);
      setState(() {
        headBytes = bytes;
      });
    }
    // setState
  }
}
